@@ -62,6 +62,10 @@
 #define	PFD_INVALID	-1
 #endif
 
+#if SCRIPT_RIPPLE_LEVEL < 2
+#error "ccscript 3 0.8.0 or later required"
+#endif
+
 namespace ost {
 
 class __EXPORT BayonneMsgport;
@@ -109,11 +113,15 @@ public:
 	static timeout_t exec_timer;
 	static unsigned compile_count;
 	static volatile bool image_loaded;
+	static bool provision_ripple;
+	static bool provision_daemon;
 	static bool provision_system;
+	static bool provision_check;
 	static bool provision_user;
+	static bool provision_test;
 	static const char *provision_server;
+	static const char *provision_libexec;
 
-	static BayonneDriver *start_driver;
 	static Audio::Encoding peer_encoding;
 	static Audio::timeout_t peer_framing;
 	static BayonneTranslator *init_translator;
@@ -281,6 +289,7 @@ public:
 		EXIT_STATE,
 		EXIT_THREAD,		// thread death notify
 		EXIT_TIMER,		// timer notified exit
+		EXIT_PARTING,		// exit a join...
 		NULL_EVENT,		// generic null event pusher
 		ERROR_STATE,		// generic enter with error
 
@@ -410,8 +419,8 @@ public:
 		TONE_STOP,
 		AUDIO_START,
 		AUDIO_STOP,
-		DTMF_START,
-		DTMF_STOP,
+		DTMF_START,	/* peer */
+		DTMF_STOP,	/* peer */
 
 		// make modes and special timeslot stuff
 
@@ -423,13 +432,11 @@ public:
 		MAKE_EXPIRED,
 		ENABLE_LOGGING,
 		DISABLE_LOGGING,
-		PART_USER,
-		PART_TIMER,
-		PART_DIGIT,
-		PART_EXIT,
+		PART_EXPIRED,
+		PART_EXITING,
+		PART_DISCONNECT,
 		JOIN_PEER,
 		PEER_WAITING,
-		PART_PEER,
 
 		// master control events
 
@@ -637,6 +644,7 @@ public:
 			{
 				const char *dial;
 				const char *exit;
+				bool dtmf;
 				BayonneSession *peer;
 				timeout_t answer_timer;
 				char digits[64];
@@ -703,22 +711,6 @@ public:
 	 */
 	static bool service(const char *svc);
 
-	/**
-	 * Used internally to compile a directory of script files.
-	 *
-	 * @param directory prefix to compile.
-	 * @param script image to build into.
-	 */
-	static void compileDir(const char *prefix, ScriptCompiler *img);
-
-	/**
-	 * Used internally to compile libexec apps wrappers.
-	 *
-	 * @param directory prefix to compile.
-	 * @param script image to build into.
-	 */
-	static void compileApps(const char *prefix, ScriptCompiler *img);
-
 	/**
 	 * Returns a session pointer for a server timeslot.  Each
 	 * server timeslot can map to a single session object.
@@ -827,11 +819,18 @@ public:
 	/**
 	 * Load a plugin module.
 	 *
-	 * @param prefix path for plugin.
 	 * @param id of plugin.
 	 * @return true if successful.
 	 */
-	static bool loadPlugin(const char *prefix, const char *path);
+	static bool loadPlugin(const char *path);
+
+        /**
+         * Load a monitoring/management module.
+         *
+         * @param id of plugin.
+         * @return true if successful.
+         */
+        static bool loadMonitor(const char *path);  
 
 	static void errlog(const char *level, const char *fmt, ...); 
 };
@@ -894,7 +893,7 @@ public:
 	 * @param iso module name to load.
 	 * @return true if successful.
 	 */
-	static BayonneTranslator *loadTranslator(const char *prefix, const char *name);
+	static BayonneTranslator *loadTranslator(const char *name);
 
 	/**
 	 * Translate a simple set of digits to spoken speech.
@@ -1205,7 +1204,10 @@ protected:
 	friend class __EXPORT BayonneMsgport;
 	static BayonneDriver *firstDriver;
 	static BayonneDriver *lastDriver;
+	static BayonneDriver *trunkDriver;
+	static BayonneDriver *protoDriver;
 	static Semaphore oink;	// the pig has been kicked!
+	static bool protocols;
 
 	BayonneSession *firstIdle, *lastIdle;
 	BayonneMsgport *msgport;
@@ -1252,6 +1254,31 @@ public:
 	 */
 	~BayonneDriver();
 
+	/**
+	 * Return flag for protocols active.
+	 */
+	static inline bool useProtocols(void)
+		{return protocols;}
+
+	/**
+	 * Return primary trunk driver, if driver trunking...
+	 */
+	static inline BayonneDriver *getTrunking(void)
+		{return trunkDriver;}
+
+	/**
+	 * Return the first loaded driver.
+	 */
+	static inline BayonneDriver *getPrimary(void)
+		{return firstDriver;}
+	
+
+	/**
+	 * Return primary protocol driver...
+	 */
+	static inline BayonneDriver *getProtocol(void)
+		{return protoDriver;}
+
 	/**
 	 * Get longest idle session to active for call processing.
 	 *
@@ -1292,7 +1319,24 @@ public:
 	 * @param driver name to load.
 	 * @return NULL or pointer to loaded driver.
 	 */
-	static BayonneDriver *loadDriver(const char *prefix, const char *id);
+	static BayonneDriver *loadDriver(const char *id);
+
+	/**
+	 * Load a bayonne trunking driver into memory, set protocols.
+	 *
+	 * @return NULL or pointer to loaded driver.
+	 * @param id of trunking driver to load.
+	 */
+	static BayonneDriver *loadTrunking(const char *id);
+
+	/**
+	 * Load a protocol driver into memory, set timeslots.
+	 *
+	 * @return NULL or pointer to loaded protocol.
+	 * @param id of protocol driver to load.
+	 * @param timeslots of protocol.
+	 */
+	static BayonneDriver *loadProtocol(const char *id, unsigned timeslots = 0);
 
 	/**
 	 * Get list of driver names into string array.
@@ -2113,8 +2157,28 @@ public:
 	inline bool signalScript(signal_t sig)
 		{return ScriptInterp::signal(sig);};
 
+	/**
+	 * Post a peer audio frame into the driver.  The frame is assumed
+	 * to either be in the format used for global peering, or, if
+	 * the driver supports setPeering, perhaps in the session selected
+	 * format.
+	 *
+	 * @return true if peer frame was posted.
+	 * @param audio frame to peer.
+	 */
 	virtual bool peerAudio(Audio::Encoded encoded);
 
+	/**
+	 * Set peer audio encoding to the encoding type and framing
+	 * specified by peer on drivers which can switch encoding.  This
+	 * can enable audio conversions to be bypassed.
+	 *
+	 * @return true if set.
+	 * @param encoding format requested.
+	 * @param frame timing to use.
+	 */
+	virtual bool setPeering(Audio::Encoding encoding, timeout_t framing);
+
 	const char *getKeyString(const char *id);
 	bool getKeyBool(const char *id);
 	long getKeyValue(const char *id);
