@@ -19,8 +19,11 @@
 using namespace ost;
 using namespace std;
 
+bool BayonneDriver::protocols = true;
 BayonneDriver *BayonneDriver::firstDriver = NULL;
 BayonneDriver *BayonneDriver::lastDriver = NULL;
+BayonneDriver *BayonneDriver::trunkDriver = NULL;
+BayonneDriver *BayonneDriver::protoDriver = NULL;
 Semaphore BayonneDriver::oink(0);
 
 BayonneDriver::BayonneDriver(Keydata::Define *pairs, const char *cfg, const char *id, bool pri) :
@@ -47,25 +50,15 @@ Keydata(pairs, getKeypath(cfg)), Mutex()
 	audio_stack = 0;
 	audio_level = 100;
 
-	if(pri)
+	if(firstDriver)
 	{
-		nextDriver = firstDriver;
-		firstDriver = this;
-		if(!lastDriver)
-			lastDriver = this;
+		lastDriver->nextDriver = this;
+		lastDriver = this;
 	}
 	else
-	{		
-		if(firstDriver)
-		{
-			lastDriver->nextDriver = this;
-			lastDriver = this;
-		}
-		else
-			firstDriver = lastDriver = this;
+		firstDriver = lastDriver = this;
 
-		nextDriver = NULL;
-	}
+	nextDriver = NULL;
 
 	timeslot = getTimeslotsUsed();
 	count = 0;
@@ -139,51 +132,123 @@ void BayonneDriver::add(BayonneSession *session)
 	}		
 }
 
-BayonneDriver *BayonneDriver::loadDriver(const char *prefix, const char *id)
+BayonneDriver *BayonneDriver::loadProtocol(const char *id, unsigned timeslots)
+{
+	char buf[65];
+	char val[16];
+	BayonneDriver *d;
+	const char *cp;
+
+	if(!id || !*id || !stricmp(id, "none"))
+		return NULL;
+
+	if(!protocols)
+	{
+		slog.error("cannot load %s; protocols disabled", id);
+		return NULL;
+	}
+
+	snprintf(val, sizeof(val), "%d", timeslots);
+	snprintf(buf, sizeof(buf), "slots.%s", id);
+	if(timeslots)
+		server->setValue(buf, val);
+
+	d = loadDriver(id);
+	if(!d)
+		return NULL;
+
+	cp = d->getLast("type");
+	if(!cp || strnicmp(cp, "proto", 5))
+	{
+		slog.error("loading driver %s as protocol; rejecting", id);
+		return NULL;
+	}			
+	return d;
+}
+
+BayonneDriver *BayonneDriver::loadTrunking(const char *id)
+{
+	BayonneDriver *d;
+	const char *cp;
+
+	if(!id || !*id || !stricmp(id, "none"))
+		return NULL;
+
+	if(trunkDriver)
+	{
+		slog.error("trunk driver %s disabled; trunking already loaded", id);
+		return NULL;
+	}
+
+	d = loadDriver(id);
+	if(!d)
+		return NULL;
+
+	cp = d->getLast("type");
+	if(!cp)
+		cp = "none";
+
+	if(!strnicmp(cp, "proto", 5))
+	{
+		slog.error("loading protocol %s for trunking; rejecting", id);
+		return NULL;
+	}
+		 
+	if(strnicmp(cp, "peer", 4))
+	{
+		protocols = false;
+		slog.warn("driver %s incapable of peering; no protocols will be loaded", id);
+	}
+
+	return d;
+}
+
+BayonneDriver *BayonneDriver::loadDriver(const char *id)
 {
 	DSO *dso;
 	BayonneDriver *d;
 	char pathbuf[256];
 	const char *cp;
 	const char *path;
+	const char *prefix = NULL;
 
 #ifdef	WIN32
+#ifdef	HAVE_TESTING
+	if(!prefix && provision_test)
+#ifdef	NDEBUG
+		prefix = "DEBUG";
+#else
+		prefix = "RELEASE";
+#endif
+#endif
 	if(!prefix)
 		prefix="C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Drivers";
 #else
+
+#ifdef	HAVE_TESTING
+	char prefixbuf[256];
+	if(!prefix && provision_test)
+	{
+		snprintf(prefixbuf, sizeof(prefixbuf), "%s/modules/%s/.libs", SOURCE_FILES, id);
+		if(!isDir(prefixbuf))
+			snprintf(prefixbuf, sizeof(prefixbuf), "%s/modules/%s", SOURCE_FILES, id);
+		prefix = prefixbuf;
+	}
+#endif
 	if(!prefix)
 		prefix=LIBDIR_FILES;
 #endif
 
-	cp = strrchr(id, '/');
-	if(!cp)
-		cp = strrchr(id, '\\');
-	if(!cp)
-		cp = strrchr(id, ':');
-
-	if(!cp)
-	{
 #ifdef	WIN32
-		snprintf(pathbuf, sizeof(pathbuf), "%s/%s." RLL_SUFFIX, prefix, id);
+	snprintf(pathbuf, sizeof(pathbuf), "%s/%s." RLL_SUFFIX, prefix, id);
 #else
-		if(!strnicmp(prefix, "..", 2))
-			snprintf(pathbuf, sizeof(pathbuf),
-				"%s/%s/.libs/%s.ivr", prefix, id, id);
-		else
-			snprintf(pathbuf, sizeof(pathbuf),
-				"%s/%s.ivr", prefix, id);
+	snprintf(pathbuf, sizeof(pathbuf), "%s/%s.ivr", prefix, id);
 #endif
-		path = pathbuf;	
-	}
-	else
-	{
-		path = id;
-		id = ++cp;
-	}
+	path = pathbuf;	
 
 	d = get(id);
 	if(d)
-		return d;
+		goto check;
 
 	if(!canAccess(path))
 	{
@@ -197,7 +262,18 @@ BayonneDriver *BayonneDriver::loadDriver(const char *prefix, const char *id)
 		errlog("error", "%s: %s", path, dso->getError());
 		return NULL;
 	}
-	return get(id);
+	d = get(id);
+check:
+	if(!d)
+		return NULL;
+
+	cp = d->getLast("type");
+	if(!strnicmp(cp, "proto", 5))
+		protoDriver = d;
+	else
+		trunkDriver = d;
+
+	return d;
 }
 	
 BayonneSpan *BayonneDriver::getSpan(unsigned id)
