@@ -753,7 +753,7 @@ Script::Name *BayonneSession::attachStart(Event *event)
 	did = getSymbol("session.dialed");
 	if(did)
 	{
-		if(img->isRipple())
+		if(provision_ripple)
 		{
 			snprintf(buf, sizeof(buf), "dialed::%s", did);
 			scr = img->getScript(buf);
@@ -772,7 +772,7 @@ Script::Name *BayonneSession::attachStart(Event *event)
 	cid = getSymbol("session.caller");
 	if(cid)
 	{
-		if(img->isRipple())
+		if(provision_ripple)
 		{
 			snprintf(buf, sizeof(buf), "caller::%s", cid);
 			scr = img->getScript(buf);
@@ -788,9 +788,9 @@ Script::Name *BayonneSession::attachStart(Event *event)
 		}
 	}
 
-	if(img->isRipple())
+	if(provision_ripple)
 	{
-		snprintf(buf, sizeof(buf), "slot::%d", timeslot);
+		snprintf(buf, sizeof(buf), "timeslot::%d", timeslot);
 		scr = img->getScript(buf);
 		if(scr)
 			goto final;
@@ -805,7 +805,7 @@ Script::Name *BayonneSession::attachStart(Event *event)
 
 	if(span)
 	{
-		if(img->isRipple())
+		if(provision_ripple)
 		{
 			snprintf(buf, sizeof(buf), "span::%d", span->id);
 			scr = img->getScript(buf);
@@ -821,15 +821,15 @@ Script::Name *BayonneSession::attachStart(Event *event)
 		}
 	}
 
-	if(img->isRipple())
-		scr = img->getScript("slot::default");
+	if(provision_ripple)
+		scr = img->getScript("timeslot::default");
 	else
 		scr = (Name *)img->getPointer("ts.default");
 	if(scr)
 		goto final;
 
 incoming:
-	if(img->isRipple())
+	if(provision_ripple)
 		scr = img->getScript("dialed::default");
 	else
 		scr = (Name *)img->getPointer("did.default");
@@ -1099,7 +1099,7 @@ void BayonneSession::makeIdle(void)
 		setOffhook(false);
 
 	if(peer)
-		part(PART_EXIT);
+		part(PART_DISCONNECT);
 
 	newTid();
 	clrAudio();
@@ -1386,6 +1386,11 @@ bool BayonneSession::peerAudio(Audio::Encoded encoded)
 	return false;
 }
 
+bool BayonneSession::setPeering(Audio::Encoding encoding, timeout_t framing)
+{
+	return false;
+}
+
 void BayonneSession::part(event_t id)
 {
 	Event event;
