@@ -1074,82 +1074,72 @@ exitkey:
 bool BayonneSession::stateJoin(Event *event)
 {
 	const char *msg;
-	const char *emsg;
-	event_t id;
-	bool rtn;
-	Event parting;
+	const char *err;
+        event_t pid = PART_DISCONNECT;
+        bool rtn;  
 
-        if(enterJoin(event))
-                return true;
+	if(enterJoin(event))
+		return true;
 
-	id = event->id;
 	switch(event->id)
 	{
-	case ENTER_STATE:
-		if(state.timeout && state.timeout != TIMEOUT_INF)
-			startTimer(state.timeout);
-		peer = state.join.peer;
-		setSymbol("script.error", "none");
+        case ENTER_STATE:
+                if(state.timeout && state.timeout != TIMEOUT_INF)
+                        startTimer(state.timeout);
+                peer = state.join.peer;
+                setSymbol("script.error", "none");
+                return true; 
+	case DTMF_KEYDOWN:
+		if(!state.join.dtmf)
+			return true;
+		event->id = DTMF_START;
+		peer->queEvent(event);
 		return true;
-	case PART_USER:
-		emsg = "user-parted";
-		msg = "part:user";
-		goto part;
-	case PART_EXIT:
-		emsg = "user-exit";
-		msg = "part:exit";
-		goto part;
-	case PART_TIMER:
-		emsg = "user-expired";
+	case DTMF_KEYUP:
+		if(!state.join.dtmf)
+		{
+			pid = PART_EXITING;
+			break;
+		}
+		event->id = DTMF_STOP;
+		peer->queEvent(event);
+		return true;
+	case TIMER_EXPIRED:
+		pid = PART_EXPIRED;
+		break;
+	case PART_EXITING:
+		msg = "part:exiting";
+		err = "part-exiting";
+		goto part;	
+	case PART_EXPIRED:
 		msg = "part:expired";
+		err = "part-expired";
 		goto part;
-	case PART_DIGIT:
-		emsg = "user-input";
-		msg = "part:input";
+	case PART_DISCONNECT:
+		msg = "part:disconnect";
+		err = "part-disconnect";
 		goto part;
 	}
 
 	rtn = enterCommon(event);
 	if(!isJoined())
 	{
-		memset(&parting, 0, sizeof(parting));
-		parting.id = PART_PEER;
-		if(!enterJoin(&parting) && !thread)
-			clrAudio();
-
-		switch(id)
-		{
-		case DTMF_KEYUP:
-			part(PART_DIGIT);
-			break;
-		case TIMER_EXPIRED:
-			part(PART_TIMER);
-			break;
-		case STOP_DISCONNECT:
-		case LINE_HANGUP:
-		case STOP_SCRIPT:
-			part(PART_EXIT);
-			break;
-		default:
-			part(PART_USER);
-		}
+		part(pid);
+		event->id = EXIT_PARTING;
+		enterJoin(event);
 	}
-
 	return rtn;
 
 part:
-	memset(&parting, 0, sizeof(parting));
-	parting.id = PART_PEER;
-	if(!enterJoin(&parting) && !thread)
-		clrAudio();	// get on other side of reset timer if thread
-
 	if(!scriptEvent(msg))
 		if(!signalScript(SIGNAL_PART))
-			error(emsg);
+			error(err);
 	setRunning();
-	return true;	
+	event->id = EXIT_PARTING;
+	enterJoin(event);
+	return true;
 }
-
+		
 bool BayonneSession::stateWait(Event *event)
 {
 	Event pe;
@@ -1778,10 +1768,9 @@ bool BayonneSession::filterPosting(Event *event)
 
 	switch(event->id)
 	{
-	case PART_DIGIT:
-	case PART_TIMER:
-	case PART_USER:
-	case PART_EXIT:
+	case PART_DISCONNECT:
+	case PART_EXPIRED:
+	case PART_EXITING:
 		if(!peer)
 			return false;
 		return true;
