@@ -201,7 +201,9 @@ void Driver::startDriver(void)
 	const char *cp;
 	unsigned max_count = ts_count;
 	cp = server->getLast("slots.sip");
+#ifdef	HAVE_EXOSIP2
 	int rtn;
+#endif
 
 	exiting = false;
 	timeslot = ts_used;
@@ -946,7 +948,7 @@ sip404:
 			if(!display || !*display)
 				display = caller;
 
-			session->setConst("session.auth", auth);
+			session->setConst("session.info", auth);
                         session->setConst("session.dialed", dialed);
                         session->setConst("session.caller", caller);
 			session->setConst("session.display", display);
@@ -1017,7 +1019,11 @@ sip404:
 				session->getSymbol("session.rtp_remote"));
 
 			memset(&event, 0, sizeof(event));
-			event.id = START_INCOMING;
+			if(!stricmp(auth, "user") || !stricmp(auth, "anon"))
+				event.id = START_DIRECT;
+			else		
+				event.id = START_INCOMING;
+
 			event.start.img = img;
 			event.start.scr = scr;
 
@@ -1029,6 +1035,10 @@ sip404:
 			}
 
 			eXosip_lock();
+			snprintf(buf, sizeof(buf), "%s@%s", 
+				session->var_sid, inet_ntoa(session->local_address.getAddress()));
+//			eXosip_set_call_reference(sevent->cid, buf);
+			session->setConst("session.callref", buf); 
 			eXosip_answer_call(sevent->did, 180, NULL);
 			eXosip_unlock();
 			break;
