@@ -19,7 +19,11 @@
 #include <cc++/process.h>
 #include <ccrtp/rtp.h>
 #undef	HAVE_CONFIG_H
+#ifdef	HAVE_EXOSIP2
+#include <eXosip2/eXosip.h>
+#else
 #include <eXosip/eXosip.h>
+#endif
 
 namespace sipdriver {
 using namespace ost;
@@ -82,15 +86,6 @@ public:
 	void refresh(void);
 	bool authenticate(Session *s);
 
-	inline uint8 getDTMFPayload(void)
-		{return dtmf_payload;};
-
-	inline uint8 getDataPayload(void)
-		{return data_payload;};
-
-	inline bool getDTMFInband(void)
-		{return dtmf_inband;};
-
 	inline Level getSilence(void)
 		{return silence;};
 };
@@ -159,6 +154,8 @@ protected:
 	Linear lbuffer;
 	Linear peer_buffer;
 	AudioCodec *peer_codec;
+	uint8 dtmf_payload, data_payload;
+	volatile bool dtmf_inband;
 
 	int cid, did;
 
