@@ -37,7 +37,10 @@ const char *Checks::chkConfig(Line *line, ScriptImage *img)
 		fname = scr->filename;
 	else
 		++fname;
-	
+
+	if(!Bayonne::isScript(scr))
+		return "config not supported outside scripts and macros";
+
 	if(getMember(line))
 		return "config uses no members";
 
@@ -112,49 +115,6 @@ const char *Checks::chkPaths(Line *line, ScriptImage *img)
 	return NULL;
 }
 
-const char *Checks::chkKey(Line *line, ScriptImage *img)
-{
-	if(getMember(line))
-		return "key doesnt use members";
-
-	if(!useKeywords(line, "=index=value"))
-		return "unknown keyword used for key";
-
-	return chkAllVars(line, img);
-}
-
-const char *Checks::chkCDR(Line *line, ScriptImage *img)
-{
-	char var[65];
-	char *p;
-	unsigned idx = 0;
-	const char *cp;
-
-	Name *scr = img->getCurrent();
-	snprintf(var, sizeof(var), "cdr.%s", scr->name);
-	p = strchr(var, ':');
-	if(p)
-		*p = 0;
-
-	if(img->getPointer(var))
-		return "cdr already assigned for this script file";
-
-	if(getMember(line))
-		return "cdr uses no members";
-
-	if(hasKeywords(line))
-		return "cdr has no keywords";
-
-	while(NULL != (cp = getOption(line, &idx)))
-	{
-		if(!isalpha(*cp) && *cp != '%')
-			return "invalid cdr entry used";
-	}
-
-	img->setPointer(var, line);
-	return "";
-}
-
 const char *Checks::chkDial(Line *line, ScriptImage *img)
 {
 	unsigned idx = 0;
@@ -187,51 +147,6 @@ const char *Checks::chkChildSignal(Line *line, ScriptImage *img)
 	return NULL;
 }
 
-const char *Checks::chkJoin(Line *line, ScriptImage *img)
-{
-	unsigned idx = 0;
-
-	if(getMember(line))
-		return "join no members used";
-
-	if(!useKeywords(line, "=timeout"))
-		return "invalid keyword for join";
-
-	if(!getOption(line, &idx))
-		return "no join session id requested";
-
-	return NULL;
-}
-
-const char *Checks::chkWait(Line *line, ScriptImage *img)
-{
-        unsigned idx = 0;
-
-        if(getMember(line))
-                return "wait no members used";
-
-        if(!useKeywords(line, "=timeout=id"))
-                return "invalid keyword for wait";
-
-        return NULL;
-}
-
-const char *Checks::chkCancel(Line *line, ScriptImage *img)
-{
-	unsigned idx = 0;
-
-	if(getMember(line))
-		return "cancel has no members";
-	
-	if(hasKeywords(line))
-		return "cancel has no keywords";
-
-	if(!getOption(line, &idx))
-		return "cancel requires at least one timeslot argument";
-
-	return NULL;
-}
-
 const char *Checks::chkTransfer(Line *line, ScriptImage *img)
 {
 	unsigned idx = 0;
@@ -300,38 +215,6 @@ const char *Checks::chkTone(Line *line, ScriptImage *img)
 	return NULL;
 }
 
-const char *Checks::chkConnect(Line *line, ScriptImage *img)
-{
-        unsigned idx = 0;
-
-        if(!useKeywords(line, "=caller=display=vars=session=timeout=tone=duration"))
-                return "invalid keyword used for dial";
-
-        if(!getOption(line, &idx))
-                return "no start script specified";
-
-	if(!getOption(line, &idx))
-		return "no number specified for dial";
-
-        return NULL;
-}
-	
-const char *Checks::chkStart(Line *line, ScriptImage *img)
-{
-	unsigned idx = 0;
-
-	if(!useKeywords(line, "=vars=session=timeout=duration"))
-		return "invalid keyword used for start";
-
-	if(!getOption(line, &idx))
-		return "no start script specified";
-
-	if(getOption(line, &idx))
-		return "only one script name used in start";
-
-	return NULL;
-}
-
 const char *Checks::chkDir(Line *line, ScriptImage *img)
 {
 	unsigned count = 0;
@@ -379,7 +262,7 @@ const char *Checks::chkLang(Line *line, ScriptImage *img)
 		return "lang has no keywords";
 
 	while(NULL != (cp = getOption(line, &idx)))
-		BayonneTranslator::loadTranslator(keypaths.getLast("phrases"), cp);
+		BayonneTranslator::loadTranslator(cp);
 		
 	return "";
 }
@@ -409,7 +292,7 @@ const char *Checks::chkLoad(Line *line, ScriptImage *img)
 	while(count < line->argc)
 	{
 		cp = line->args[count++];
-		loadPlugin(keypaths.getLast("modules"), cp);
+		loadPlugin(cp);
 	}
 	BayonneService::start();
 	
@@ -799,223 +682,4 @@ const char *Checks::chkSleep(Line *line, ScriptImage *img)
 	return NULL;
 }
 
-const char *Checks::chkRegister(Line *line, ScriptImage *img)
-{
-	const char *cp = getMember(line);
-	Name *scr = img->getCurrent();
-	BayonneDriver *driver;
-
-	if(scr->access != ScriptInterp::scrPUBLIC)
-		return "cannot register non-public script";
-
-	if(cp)
-		++cp;
-
-	driver = BayonneDriver::get(cp);
-		
-	if(!driver)
-	{
-		slog.warn("cannot register %s with %s", scr->name, cp);
-		return "";
-	}
-	return driver->registerScript(img, line);
-}
-		
-const char *Checks::chkAssign(Line *line, ScriptImage *img)
-{
-	const char *cp = getMember(line);
-	Name *scr = img->getCurrent();
-	unsigned idx = 0, spid;
-	char tag[65];
-	BayonneDriver *driver;
-	BayonneSession *s;
-
-	if(hasKeywords(line))
-		return "keywords not used for assign";
-
-	if(!line->argc)
-		return "missing entries to assign";
-
-	if(scr->access != ScriptInterp::scrPUBLIC)
-		return "cannot assign non-public script";	
-
-	if(!stricmp(line->cmd, "incoming"))
-		goto dnis;
-
-	if(!stricmp(line->cmd, "caller"))
-		goto cid;
-
-	if(!stricmp(line->cmd, "incoming.timeslot"))
-		goto timeslot;
-
-	if(!stricmp(line->cmd, "incoming.span"))
-		goto span;
-
-	if(!strnicmp(line->cmd, "incoming.", 9))
-		return "invalid member for incoming"; 
-
-	if(cp && *cp == '.')
-		++cp;
-
-	if(cp)
-	{
-		if(!stricmp(cp, "timeslot"))
-			goto timeslot;
-
-		if(!stricmp(cp, "span"))
-			goto span;
-
-		if(!stricmp(cp, "dnis"))
-			goto dnis;
-
-		if(!stricmp(cp, "did"))
-			goto dnis;
-
-		if(!stricmp(cp, "cid"))
-			goto cid;
-
-		driver = BayonneDriver::get(cp);
-		if(!driver)
-		{
-			slog.warn("cannot assign %s with %s", scr->name, cp);
-			return "";
-		}
-		return driver->assignScript(img, line);
-	}
-
-timeslot:
-	while(NULL != (cp = getOption(line, &idx)))
-	{
-		if(!stricmp(cp, "default"))
-		{
-			slog.debug("assigning unassigned timeslots to %s", scr->name);
-			img->setPointer("ts.default", scr);
-			continue;
-		}
-		s = getSid(cp);
-		if(s && s->getInterface() == IF_INET)
-			s = NULL;
-		if(!s)
-		{
-			slog.error("server cannot assign %s; invalid timeslot", cp);
-			continue;
-		}
-		slog.debug("assigning timeslot %s to %s", cp, scr->name);
-		snprintf(tag, sizeof(tag), "ts.%d", s->getSlot());
-		img->setPointer(tag, scr);
-	}
-	return "";
-
-span:
-	while(NULL != (cp = getOption(line, &idx)))
-	{
-		spid = atoi(cp);
-		slog.debug("assigning span %s to %s", cp, scr->name);
-		snprintf(tag, sizeof(tag), "span.%d", spid);
-		img->setPointer(tag, scr);
-	}
-	return "";
-
-cid:
-	while(NULL != (cp = getOption(line, &idx)))
-	{
-		slog.debug("assigning caller number %s to %s", cp, scr->name);
-		snprintf(tag, sizeof(tag), "cid.%s", cp);
-		img->setPointer(tag, scr);
-	}
-	return "";
-
-dnis:
-        while(NULL != (cp = getOption(line, &idx)))
-        {
-		if(!stricmp(cp, "default"))
-		{
-			cp = "default";
-			slog.debug("assigning inbound default %s", scr->name);
-		}
-		else
-	                slog.debug("assigning dialed number %s to %s", cp, scr->name);
-                snprintf(tag, sizeof(tag), "did.%s", cp);
-                img->setPointer(tag, scr);
-        }
-        return "";
-}	
-
-const char *Checks::chkSelect(Line *line, ScriptImage *img)
-{
-	const char *cp = getMember(line);
-	Name *scr = img->getCurrent();
-	timeslot_t ts;
-	unsigned idx = 0, spid;
-	interface_t iface;
-	BayonneSession *session;
-
-	if(hasKeywords(line))
-		return "keywords not used for select";
-
-	if(!line->argc)
-		return "missing entries to select";
-
-	if(scr->access != ScriptInterp::scrPUBLIC)
-		return "cannot select from non-public script";	
-
-	if(cp && *cp == '.')
-		++cp;
-
-	if(cp)
-	{
-		if(!stricmp(cp, "timeslot"))
-			goto timeslot;
-
-		if(!stricmp(cp, "span"))
-			goto span;
-
-		return "unknown form of select";
-	}
-
-timeslot:
-	while(NULL != (cp = getOption(line, &idx)))
-	{
-		ts = toTimeslot(cp);
-		if(ts == NO_TIMESLOT)
-		{
-			slog.error("server cannot select %s; no such timeslot", cp);
-			continue;
-		}
-		session = getSession(ts);
-		if(!session)
-		{
-			slog.error("server cannot select %s; timeslot not allocated", cp);
-			continue;
-		}
-		iface = session->getInterface();
-		switch(iface)
-		{
-		case IF_INET:
-			slog.error("server cannot select %s; non-physical port", cp);
-			break;
-		default:
-			slog.debug("selecting timeslot %s for %s", cp, scr->name);
-			img->addSelect(line);
-		}
-	}
-	return "";
-
-span:
-	while(NULL != (cp = getOption(line, &idx)))
-	{
-		spid = atoi(cp);
-		if(BayonneSpan::get(spid))
-		{
-			slog.debug("selecting span %s for %s", cp, scr->name);
-			img->addSelect(line);
-		}
-		else
-			slog.error("cannot select span %d; does not exist", spid);
-
-	}
-	return "";
-}	
-
-
 } // end namespace
