@@ -15,6 +15,7 @@
 // Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 #include <cc++/process.h>
+#include <cc++/slog.h>
 #include "server.h"
 
 #ifndef	WIN32
@@ -83,10 +84,6 @@ static Keydata::Define paths[] = {
 	{"logfiles", LOG_FILES},
 	{"runfiles", RUN_FILES},
 	{"config", CONFIG_FILES},
-	{"apps", CONFIG_FILES},
-	{"modules", MODULE_FILES},
-	{"drivers", DRIVER_FILES},
-	{"phrases", PHRASE_FILES},
 	{"scripts", SCRIPT_FILES},
 	{"macros", MACRO_FILES},
 	{"prompts", PROMPT_FILES},
@@ -103,10 +100,15 @@ static Keydata::Define server[] = {
 	{"voice", "none/prompts"},
 	{"state", "init"},
 	{"logging", "warn"},
+	{"monitoring", "tcp"},
+	{"binding", "ivrscript"},
+	{NULL, NULL}};
+
+static Keydata::Define switchkeys[] = {
+	{"timeslots", "32"},
 	{NULL, NULL}};
 
 static Keydata::Define engine[] = {
-	{"timeslots", "32"},
 	{"priority", "0"},
 	{"scheduler", "default"},
 	{"events", "32"},
@@ -119,20 +121,96 @@ static Keydata::Define engine[] = {
 Keydata keypaths(paths, "/bayonne/paths");
 Keydata keyserver(server, "/bayonne/server");
 Keydata keyengine(engine, "/bayonne/engine");
+Keydata keyswitch(switchkeys, "/bayonne/switch");
 #else
 Keydata keypaths(paths, "/bayonne/server/paths");
 Keydata keyserver(server, "/bayonne/server/server");
 Keydata keyengine(engine, "/bayonne/server/engine");
+Keydata keyswitch(switchkeys, "/bayonne/server/switch");
 #endif
 Keydata keyoptions;
 
-static void commonConfig(void)
+bool loadBinder(const char *path)
+{
+        char pathbuf[256];
+        const char *cp, *kv;
+        const char *prefix = NULL;
+        DSO *dso;  
+
+#ifdef  WIN32
+#ifdef  HAVE_TESTING
+        if(!prefix && Bayonne::provision_test)
+#ifdef  NDEBUG
+                prefix = "DEBUG";
+#else    
+                prefix = "RELEASE";
+#endif
+#endif   
+        if(!prefix)
+	 	prefix = "C:\\Program Files\\Common Files\\GNU Telephony\\Bayonne Binder";
+#else
+
+#ifdef  HAVE_TESTING
+        char prefixbuf[256];
+
+        if(!prefix && Bayonne::provision_test && !strchr(path, '/'))
+        {
+                snprintf(prefixbuf, sizeof(prefixbuf),
+                        "%s/binders/%s/.libs", SOURCE_FILES, path);
+                if(!isDir(prefixbuf))
+                        snprintf(prefixbuf, sizeof(prefixbuf),
+                                "%s/binders/%s", SOURCE_FILES, path);
+                prefix = prefixbuf;
+        }
+#endif
+        if(!prefix)
+                prefix = LIBDIR_FILES;
+#endif 
+
+#ifdef  WIN32
+        snprintf(pathbuf, sizeof(pathbuf), "%s/%s." RLL_SUFFIX, prefix, path);
+#else
+        snprintf(pathbuf, sizeof(pathbuf), "%s/%s.bin", prefix, path);
+#endif  
+
+        cp = path;
+        path = pathbuf;
+
+        kv = runtime.getLast(path); 
+
+        if(kv)
+        {
+                if(!stricmp(kv, "loaded"))
+                        return true;
+                return false;
+        }
+
+        if(!canAccess(path))
+        {
+                Bayonne::errlog("access", "cannot load %s", path);
+                return false;
+        }  
+
+        dso = new DSO(path);
+        if(!dso->isValid())
+        {
+                kv = dso->getError();
+                runtime.setValue(path, kv);
+                Bayonne::errlog("error", "cannot initialize %s", path);
+                return false;
+        }
+        runtime.setValue(path, "loaded");
+        return true;
+}                     
+
+void liveConfig(void)
 {
 	char path[256];
 	char lang[32];
 	const char *env;
 	char *p;
 	const char *cp;
+	unsigned timeslots = atoi(keyswitch.getLast("timeslots"));
 
 #ifdef	WIN32
         char nodename[MAX_COMPUTERNAME_LENGTH + 1];
@@ -175,13 +253,10 @@ static void commonConfig(void)
 	keyserver.setValue("platform", "w32");
 	keyserver.setValue("cpu", cpu);
 
-	snprintf(path, sizeof(path), "%s/bayonne.key", keypaths.getLast("datafiles"));
-	keypaths.setValue("keysave", path);
-	snprintf(path, sizeof(path), "%s/bayonne.tmp", keypaths.getLast("datafiles"));
-	keypaths.setValue("keytemp", path);
 #else
 	struct utsname uts;
 	char hostname[128];
+	char *userid;
 	uname(&uts);
 	memset(hostname, 0, sizeof(hostname));
 	gethostname(hostname, sizeof(hostname) - 1);
@@ -195,25 +270,31 @@ static void commonConfig(void)
 	
 	keyserver.setValue("platform", uts.sysname);
 	keyserver.setValue("cpu", uts.machine);
+	userid = getenv("USER");
 
-	keypaths.setValue("tmp", "/tmp/.bayonne");
-	purgedir("/tmp/.bayonne");
-	Dir::create("/tmp/.bayonne");
+	if(!userid || !stricmp(userid, "root"))
+		userid="bayonne";	
+
+	snprintf(path, sizeof(path), "/tmp/bayonne-%s", userid);
+	keypaths.setValue("tmp", path);
+	purgedir(path);
+	Dir::create(path);
 
 	if(canModify("/dev/shm"))
 	{
-		keypaths.setValue("tmpfs", "/dev/shm/.bayonne");
-		purgedir("/dev/shm/.bayonne");
-		Dir::create("/dev/shm/.bayonne");
+		snprintf(path, sizeof(path), "/dev/shm/bayonne-%s", userid);
+		keypaths.setValue("tmpfs", path);
+		purgedir(path);
+		Dir::create(path);
 	}
 	else
-		keypaths.setValue("tmpfs", "/tmp/.bayonne");
+		keypaths.setValue("tmpfs", path);
 
-	snprintf(path, sizeof(path), "%s/bayonne.keys", keypaths.getLast("runfiles"));
-	keypaths.setValue("keysave", path);
-	snprintf(path, sizeof(path), "%s/.bayonne.keys", keypaths.getLast("runfiles"));
-	keypaths.setValue("keytemp", path);
 #endif
+	cp = keyoptions.getLast("prefix");
+	if(cp && *cp)
+		chdir(cp);
+
 	env = Process::getEnv("LANG");
 	if(env)
 	{
@@ -341,20 +422,15 @@ static void commonConfig(void)
 #endif
 	Script::exec_token = "bayonne:";
 	Script::exec_prefix = "exec";
+
+        Bayonne::allocate(timeslots, dynamic_cast<ScriptCommand *>(&runtime)); 
 }
 
+#ifdef	HAVE_TESTING
+
 void testConfig(char *argv0)
 {
 #ifdef	WIN32
-#ifdef	_DEBUG
-	keypaths.setValue("phrases", "Debug");
-	keypaths.setValue("drivers", "Debug");
-	keypaths.setValue("modules", "Debug");
-#else
-        keypaths.setValue("phrases", "Release");
-        keypaths.setValue("drivers", "Release");
-        keypaths.setValue("modules", "Release"); 
-#endif
 	keypaths.setValue("prompts", "../audio");
 	keypaths.setValue("scripts", "../scripts");
 	keypaths.setValue("macros", "../scripts");
@@ -367,20 +443,9 @@ void testConfig(char *argv0)
 	Process::setEnv("SPANCONFIG", "../config/spans.conf", true);
 #else
 	char pbuf[256];
-	char *p = strrchr(argv0, '/');
-	if(p)
-	{
-		*p = 0;
-		chdir(p);
-		getcwd(pbuf, sizeof(pbuf));
-	}
-	else
-		getcwd(pbuf, sizeof(pbuf));
-
+	getcwd(pbuf, sizeof(pbuf));
+	keyoptions.setValue("prefix", "");
 	keypaths.setValue("libexec", pbuf);
-	keypaths.setValue("modules", "../modules");
-	keypaths.setValue("drivers", "../modules");
-	keypaths.setValue("phrases", "../modules/languages/.libs");
 	keypaths.setValue("btsexec", SOURCE_FILES "/utils/btsexec");
 	keypaths.setValue("prompts", SOURCE_FILES "/audio");
 	keypaths.setValue("scripts", SOURCE_FILES "/scripts");
@@ -390,14 +455,18 @@ void testConfig(char *argv0)
 	keypaths.setValue("logfiles", SOURCE_FILES "/server/tempfiles");
 	keypaths.setValue("runfiles", SOURCE_FILES "/server/tempfiles");
 #endif
+	Bayonne::provision_test = true;
+	Bayonne::provision_daemon = false;
 	runtime.setValue("virtual.tts", "theta");
 	keypaths.setValue("modexec", "../scripts");
 	Dir::create("tempfiles");
 	keyserver.setValue("state", "test");
 	keyserver.setValue("logging", "debug");
-	commonConfig();
+	keyserver.setValue("monitoring", "no");
 }	
 
+#endif
+
 void loadConfig(void)
 {
 #ifdef	WIN32
@@ -441,6 +510,7 @@ void loadConfig(void)
 		keypaths.load("~bayonne/paths");
 		keyserver.load("~bayonne/server");
 		keyengine.load("~bayonne/engine");
+		keyswitch.load("~bayonne/switch");
 		runtime.loadPrefix("virtual", "~bayonne/virtual");
 	}
 
@@ -449,6 +519,7 @@ void loadConfig(void)
 		keypaths.load("/bayonne/provision/paths");
 		keyserver.load("/bayonne/provision/server");
 		keyengine.load("/bayonne/provision/engine");
+		keyswitch.load("/bayonne/provision/switch");
 		runtime.loadPrefix("virtual", "/bayonne/provision/virtual");
 	}
 
@@ -489,16 +560,10 @@ void loadConfig(void)
 	}
 live:
 #endif
-	chdir(keypaths.getLast("datafiles"));
+	keyoptions.setValue("prefix", keypaths.getLast("datafiles"));
 	keyserver.setValue("state", "live");
 
 	// only for live server...
-
-#ifdef	SCRIPT_APPS_WRAPPER
-	runtime.setValue("apps", keypaths.getLast("apps"));
-#endif
-
-	commonConfig();
 }
 
 bool parseConfig(char **argv)
@@ -509,17 +574,11 @@ bool parseConfig(char **argv)
 	char *option;
 	char *script = NULL;
 	char *argv0 = *(argv++);
-	char *cmd = *(argv++);
-	char *driver = NULL;
 	char *ext;
 	unsigned scrcount = 0;
-	unsigned timeslots = atoi(keyengine.getLast("timeslots"));
 	unsigned minslots = 0;
 	bool live = true;
 
-	if(**argv != '-')
-		driver=*(argv++);
-
 retry:
 	if(!*argv)
 		goto skip;
@@ -534,13 +593,58 @@ retry:
         if(!strnicmp("--", option, 2))
                 ++option;
 
+#ifdef	HAVE_TESTING
 	if(!strnicmp(option, "-driver=", 8))
 	{
-		driver = option + 8;
+		keyoptions.setValue("driver", option + 8);
 		++argv;
 		goto retry;
 	} 
+
+        if(!strnicmp(option, "-binding=", 9))
+        {
+                keyserver.setValue("binding", option + 9);    
+                ++argv;
+                goto retry;
+        }  
+
+        if(!strnicmp(option, "-trunking=", 10))
+        {
+                keyswitch.setValue("trunking", option + 10);    
+                ++argv;
+                goto retry;
+        }
+
+
+
+        if(!strnicmp(option, "-protocol=", 10))
+        {
+                keyswitch.setValue("protocol", option + 10);  
+                ++argv;
+                goto retry;
+        }  
+            
+        if(!strnicmp(option, "-test=", 6))
+        {
+		testConfig(argv0);
+                keyoptions.setValue("driver", option + 6);
+                ++argv;
+                goto retry;
+        }  
 	
+	if(!stricmp(option, "-test"))
+	{
+		++argv;
+		if(!*argv)
+		{
+			cerr << "bayonne: -test: missing driver" << endl;
+			exit(-1);
+		}
+		testConfig(argv0);
+		keyoptions.setValue("driver", *(argv++));
+		goto retry;
+	}
+
 	if(!strnicmp(option, "-logging=", 9))
         {
                 keyserver.setValue("logging", option + 9);
@@ -550,14 +654,14 @@ retry:
 
 	if(!strnicmp(option, "-scripts=", 9))
 	{
-		runtime.setValue("scripts", option + 9);
+		keypaths.setValue("scripts", option + 9);
 		++argv;
 		goto retry;
 	}
 
 	if(!strnicmp(option, "-macros=", 8))
 	{
-		runtime.setValue("include", option + 8);
+		keypaths.setValue("macros", option + 8);
 		++argv;
 		goto retry;
 	} 
@@ -571,13 +675,16 @@ retry:
             
 	if(!stricmp(option, "-check"))
 	{
-		live = false;
+		keyserver.setValue("logging", "debug");
+		Bayonne::provision_check = true;
 		++argv;
 		goto retry;
 	}
+#endif
 
 	if(!strnicmp(option, "-vvv", 4))
 	{
+		Bayonne::provision_daemon = false;
 		keyserver.setValue("logging", "debug");
 		++argv;
 		goto retry;
@@ -585,6 +692,7 @@ retry:
 
         if(!strnicmp(option, "-vv", 4))
         {
+		Bayonne::provision_daemon = false;
                 keyserver.setValue("logging", "notice");
                 ++argv;
                 goto retry;
@@ -592,6 +700,7 @@ retry:
 
         if(!stricmp(option, "-v"))
         {
+		Bayonne::provision_daemon = false;
                 keyserver.setValue("logging", "error");
                 ++argv;
                 goto retry;
@@ -605,24 +714,7 @@ retry:
 		goto retry;
 	}
 
-	if(!strnicmp(option, "-sip=", 5))
-	{
-		runtime.setValue("slots.sip", option + 5);
-		keyoptions.setValue("sip.stack", option + 5);
-		minslots += atoi(option + 5);
-		++argv;
-		goto retry;
-	} 
-
-        if(!strnicmp(option, "-h323=", 6))
-        {
-		runtime.setValue("slots.h323", option + 6);
-                keyoptions.setValue("h323.stack", option + 6);
-		minslots += atoi(option + 6);
-                ++argv;
-                goto retry;            
-        } 
-
+#ifdef	HAVE_TESTING
 	if(!strnicmp(option, "-voice=", 7))
 	{
 		keyserver.setValue("voice", option + 7);
@@ -640,7 +732,7 @@ retry:
 
         if(!strnicmp(option, "-timeslots=", 11))
         {
-		timeslots = atoi(option + 11);
+		keyswitch.setValue("timeslots", option + 11);
                 ++argv;
                 goto retry;
         }
@@ -650,7 +742,7 @@ retry:
                 ++argv;
                 if(!*argv)
                 {
-                        cerr << "bayonne: " << cmd << ": -libexec: missing argument" << endl;
+                        cerr << "bayonne: -libexec: missing argument" << endl;
                         exit(-1);
                 }
                 keypaths.setValue("libexec", *(argv++));
@@ -662,10 +754,10 @@ retry:
                 ++argv;
                 if(!*argv)
                 {
-			cerr << "bayonne: " << cmd << ": -scripts: missing argument" << endl;
+			cerr << "bayonne: -scripts: missing argument" << endl;
                         exit(-1);
                 }
-                runtime.setValue("scripts", *(argv++));
+                keypaths.setValue("scripts", *(argv++));
                 goto retry;
         }
            
@@ -675,10 +767,10 @@ retry:
                 ++argv;
                 if(!*argv)
                 {
-			cerr << "bayonne: " << cmd << ": -macros: missing argument" << endl;
+			cerr << "bayonne: -macros: missing argument" << endl;
                         exit(-1);
                 }
-                runtime.setValue("include", *(argv++));
+                keypaths.setValue("macros", *(argv++));
                 goto retry;
         } 
 
@@ -687,7 +779,7 @@ retry:
                 ++argv;
                 if(!*argv)
                 {
-			cerr << "bayonne: " << cmd << ": -logging: missing argument" << endl;
+			cerr << "bayonne: -logging: missing argument" << endl;
                         exit(-1);
                 }
                 keyserver.setValue("logging", *(argv++));
@@ -699,7 +791,7 @@ retry:
                 ++argv;
                 if(!argv) 
                 {
-        		cerr << "bayonne: " << cmd << ": -location: missing argument" << endl;
+        		cerr << "bayonne: -location: missing argument" << endl;
                         exit(-1);
                 }      
 		Process::setEnv("LANG", *argv, true);
@@ -713,7 +805,7 @@ retry:
 		++argv;
 		if(!argv)
 		{
-			cerr << "bayonne: " << cmd << ": -voice: missing argument" << endl;
+			cerr << "bayonne: -voice: missing argument" << endl;
 			exit(-1);
 		}
 		keyserver.setValue("voice", *(argv++));
@@ -725,131 +817,70 @@ retry:
                 ++argv;
                 if(!*argv)
                 {
-			cerr << "bayonne: " << cmd << ": -driver: missing argument" << endl;
+			cerr << "bayonne: -driver: missing argument" << endl;
                         exit(-1);
                 }
-                driver = *(argv++);
+                keyoptions.setValue("driver", *(argv++));
                 goto retry;
         }
 
-	if(!stricmp(option, "-sip"))
-	{
-		++argv;
-		if(!*argv)
-		{
-			cerr << "bayonne: " << cmd << ": -sip: missing timeslots" << endl;
-			exit(-1);
-		}
-		runtime.setValue("slots.sip", *argv);
-		keyoptions.setValue("sip.stack", *(argv++));
-		goto retry;
-	}
+        if(!stricmp(option, "-binding"))
+        {
+                ++argv;    
+                if(!*argv)
+                {
+                        cerr << "bayonne: -binding: missing argument" << endl;
+                        exit(-1);
+                }
+                keyserver.setValue("binding", *(argv++));
+                goto retry;
+        } 
 
-        if(!stricmp(option, "-h323"))      
+        if(!stricmp(option, "-trunking"))
         {
                 ++argv;
                 if(!*argv)
-                {            
-        		cerr << "bayonne: " << cmd << ": -h323: missing timeslots" << endl;                              
-			exit(-1);
+                {
+                        cerr << "bayonne: -trunking: missing argument" << endl;
+                        exit(-1);
                 }
-		runtime.setValue("slots.h323", *argv);
-                keyoptions.setValue("h323.stack", *(argv++));
+                keyswitch.setValue("trunking", *(argv++));
                 goto retry;
-        }
-           
+        }  
+
+        if(!stricmp(option, "-protocol"))
+        {
+                ++argv;
+                if(!*argv)
+                {
+                        cerr << "bayonne: -protocol: missing argument" << endl;
+                        exit(-1);
+                }
+                keyswitch.setValue("protocol", *(argv++));
+                goto retry;
+        }  
+
         if(!stricmp(option, "-timeslots"))
         {
                 ++argv;
                 if(!*argv)
                 {
-			cerr << "bayonne: " << cmd << ": -timeslots: missing argument" << endl;
+			cerr << "bayonne: -timeslots: missing argument" << endl;
                         exit(-1);
                 }
-		timeslots = atoi(*(argv++));
+		keyswitch.setValue("timeslots", *(argv++));
                 goto retry;
 	}
+#endif
 
 skip:
-	if(!driver && live)
-	{
-		cerr << "bayonne: driver missing" << endl;
-		exit(-1);
-	}
-
-	if(live)
-	{
-#ifdef	WIN32
-		Process::setEnv("DISPLAY", "yes", true);
-		if(!stricmp(driver, "console"))
-		{
-			Process::setEnv("DISPLAY", "", true);
-			driver = "soundcard";
-		}
-#else
-		if(!stricmp(driver, "console"))
-		{
-			Process::setEnv("DISPLAY", "", true);
-			driver = "soundcard";
-		}
-#endif
-
-		ext = strchr(driver, ':');
-		if(ext)
-		{
-			*(ext++) = 0;
-			minslots += atoi(ext);
-			snprintf(buffer, sizeof(buffer), "slots.%s", driver);
-			runtime.setValue(buffer, ext);
-		}
-
-		if(timeslots < minslots)
-			timeslots = minslots;
-
-		snprintf(buffer, sizeof(buffer), "%s.stack", driver);
-		keyoptions.setValue(buffer, "0");
-		
-		keyserver.setValue("driver", driver);
-		snprintf(path, 10, "%d", timeslots);
-		keyserver.setValue("timeslots", path);
- 
-		prefix = keypaths.getLast("drivers");
-#ifdef	WIN32
-		snprintf(path, sizeof(path), "%s/%s" RLL_SUFFIX, prefix, driver);
-#else
-		if(!strnicmp(prefix, "..", 2))
-			snprintf(path, sizeof(path), "%s/%s/.libs/%s.ivr", prefix, driver, driver);
-		else
-			snprintf(path, sizeof(path), "%s/%s.ivr", prefix, driver);
-#endif
-		keyoptions.setValue("driver", path);
-
-		if(!canAccess(path))
-		{
-			cerr << "server exiting; " << path << " missing" << endl;
-			exit(-1);
-		}
-	}
-	
 	while(*argv)
 	{
 		ext = strrchr(*argv, '.');
 		if(!ext)
-		{
-			prefix = keypaths.getLast("modules");
-#ifdef	WIN32
-			snprintf(path, sizeof(path), "%s/%s" RLL_SUFFIX, prefix, *argv);
-#else
-			if(!strnicmp(prefix, "..", 2))
-				snprintf(path, sizeof(path), "%s/%s/.libs/%s.dso", prefix, *argv, *argv);
-			else
-				snprintf(path, sizeof(path), "%s/%s.dso", prefix, *argv);
-#endif			
-			if(!canAccess(path))
-				cerr << "bayonne: " << *argv << ": cannot access" << endl;
-			else
-				keyoptions.setValue("modules", path);
-		}
+			keyoptions.setValue("modules", *argv);
+		else if(!stricmp(ext, ".conf") || !stricmp(ext, ".ini"))
+			slog.error("bayonne: %s: invalid script file", *argv);
 		else if(!stricmp(ext, ".mac") || !stricmp(ext, ".scr") || strstr(Script::exec_extensions, ext))
 		{
 			prefix = strrchr(*argv, '/');
@@ -861,6 +892,14 @@ skip:
 			if(prefix)
 				++prefix;
 
+			if(!prefix)
+			{
+				getcwd(path, sizeof(path));
+				addString(path, sizeof(path), "/");
+				addString(path, sizeof(path), *argv);
+				prefix = path;
+			}
+
 			if(!canAccess(*argv))
 				cerr << "bayonne: " << *argv << ": cannot access" << endl;
 			else
@@ -883,8 +922,6 @@ skip:
 		++argv;
 	}
 
-	Bayonne::allocate(timeslots, dynamic_cast<ScriptCommand *>(&runtime));
-
 	if(!script) 
 	{
 		if(!runtime.getLast("scripts"))
@@ -924,6 +961,7 @@ skip:
 	return true;
 }		
 
+#ifdef	HAVE_TESTING
 void dumpConfig(Keydata &keydef)
 {
 	unsigned count = keydef.getCount();
@@ -935,6 +973,7 @@ void dumpConfig(Keydata &keydef)
 		++keys;
 	}
 }
+#endif
 
 void purgedir(const char *dir)
 {
