@@ -29,26 +29,8 @@ ScriptRuntime()
 	static ScriptInterp::Define interp[] = {
 		{"config", true, (Method)&ScriptMethods::scrNop,
 			(Check)&Checks::chkConfig},
-		{"key", true, (Method)&Methods::scrKey,
-			(Check)&Checks::chkKey},
 		{"dial", false, (Method)&Methods::scrDial,
 			(Check)&Checks::chkDial},
-		{"start", false, (Method)&Methods::scrStart,
-			(Check)&Checks::chkStart},
-		{"join", false, (Method)&Methods::scrJoin,
-			(Check)&Checks::chkJoin},
-		{"wait", false, (Method)&Methods::scrWait,
-			(Check)&Checks::chkWait},
-		{"busysignal", false, (Method)&Methods::scrSignal,
-			(Check)&Checks::chkSignal},
-		{"failsignal", false, (Method)&Methods::scrSignal,
-			(Check)&Checks::chkSignal},
-		{"connect", false, (Method)&Methods::scrStart,
-			(Check)&Checks::chkConnect},
-		{"detach", true, (Method)&Methods::scrDetach,
-			(Check)&Checks::chkCancel},
-		{"cancel", true, (Method)&Methods::scrCancel,
-			(Check)&Checks::chkCancel},
 		{"dialtone", false, (Method)&Methods::scrTone,
 			(Check)&Checks::chkTone},
                 {"busytone", false, (Method)&Methods::scrTone,
@@ -95,18 +77,6 @@ ScriptRuntime()
 			(Check)&ScriptChecks::chkOnlyCommand},
                 {"hangup", false, (Method)&Methods::scrHangup, 
                         (Check)&ScriptChecks::chkOnlyCommand},
-		{"cdr", false, (Method)&ScriptMethods::scrNop,
-			(Check)&Checks::chkCDR},
-		{"select", false, (Method)&ScriptMethods::scrNop,
-			(Check)&Checks::chkSelect},
-		{"incoming", false, (Method)&ScriptMethods::scrNop,
-			(Check)&Checks::chkAssign},
-		{"caller", false, (Method)&ScriptMethods::scrNop,
-			(Check)&Checks::chkAssign},
-		{"assign", false, (Method)&ScriptMethods::scrNop,
-			(Check)&Checks::chkAssign},
-                {"register", false, (Method)&ScriptMethods::scrNop,
-                        (Check)&Checks::chkRegister},
 		{"collect", false, (Method)&Methods::scrCollect,
 			(Check)&Checks::chkCollect},
 		{"keyinput", false, (Method)&Methods::scrKeyinput,
@@ -208,7 +178,8 @@ ScriptRuntime()
 	ScriptInterp::addConditional("voice", &testVoice);
 	ScriptInterp::addConditional("lang", &testLang);
 	ScriptInterp::addConditional("language", &testLang);
-	ScriptInterp::addConditional("key", &testKey);
+
+	ripple = true;
 }
 
 unsigned long Runtime::getTrapMask(const char *trapname)
@@ -477,11 +448,6 @@ bool Runtime::testVoice(ScriptInterp *interp, const char *v)
 	return (s->audio.getVoicelib(v) != NULL);
 }
 
-bool Runtime::testKey(ScriptInterp *interp, const char *v)
-{
-	return PersistProperty::test(v);
-}
-
 bool Runtime::testLang(ScriptInterp *interp, const char *v)
 {
 	BayonneSession *s = (BayonneSession *)(interp);
@@ -532,6 +498,7 @@ static void readline(char *buf, unsigned max)
 
 bool Runtime::startSelect(const char *name, const char *dial, const char *caller, const char *display)
 {
+	BayonneDriver *trunk = BayonneDriver::getTrunking();
 	BayonneSpan *span;
 	BayonneSession *session;
 	ScriptImage *img = useImage();
@@ -545,8 +512,8 @@ bool Runtime::startSelect(const char *name, const char *dial, const char *caller
 	if(!scr || !scr->select || scr->access != scrPUBLIC)
 	{
 		endImage(img);
-		if(Bayonne::start_driver && scr)
-			return startDriver(start_driver, name, dial, caller, display);
+		if(trunk && scr)
+			return startDriver(trunk, name, dial, caller, display);
 		return false;
 	}
 
@@ -702,7 +669,7 @@ bool Runtime::command(char *cmd)
 		cmd = strtok_r(NULL, " \t\r\n", &tok);
 		while(cmd)
 		{
-			BayonneTranslator::loadTranslator(keypaths.getLast("phrases"), cmd);
+			BayonneTranslator::loadTranslator(cmd);
 			cmd = strtok_r(NULL, " \t\r\n", &tok);
 		}
 		return true;
@@ -713,7 +680,7 @@ bool Runtime::command(char *cmd)
 		cmd = strtok_r(NULL, " \t\r\n", &tok);
 		if(!cmd)
 			return false;
-		rtn = Bayonne::loadPlugin(keypaths.getLast("modules"), cmd);
+		rtn = Bayonne::loadPlugin(cmd);
 		if(rtn)
 			BayonneService::start();
 		return rtn;
@@ -788,10 +755,38 @@ skipcerr1:
 	
 void Runtime::process(void)
 {
+	FILE *fp;
 	char buf[256];
 	char *cp;
 	int pid;
 
+	snprintf(buf, sizeof(buf), "%s/provision.conf", keypaths.getLast("config"));
+	if(!isFile(buf))
+		snprintf(buf, sizeof(buf), "%s/startup.conf", keypaths.getLast("config"));
+	
+	fp = fopen(buf, "r");
+	if(fp)
+	{
+		for(;;)
+		{
+			fgets(buf, sizeof(buf), fp);
+			if(feof(fp))
+				break;
+			cp = buf;
+                	while(isspace(*cp))
+                        	++cp;
+
+			if(*cp == '[')
+				break;
+
+			if(!isalpha(*cp))
+				continue;
+
+			command(cp);                               
+		}
+		fclose(fp);
+	}
+
 	snprintf(buf, sizeof(buf), "%s/bayonne.ctrl", keypaths.getLast("runfiles"));
 	remove(buf);
 	mkfifo(buf, 0770);
