@@ -37,7 +37,7 @@ static BOOL WINAPI stop(DWORD code)
 
 	BayonneService::stop();
 	BayonneDriver::stop();
-	PersistProperty::save();
+	ScriptBinder::shutdown();
 
 	if(code)
 		Bayonne::errlog("failed", "server exiting; reason=%d", code);
@@ -65,7 +65,10 @@ static RETSIGTYPE stop(int signo)
 
 	BayonneService::stop();
 	BayonneDriver::stop();
-	PersistProperty::save();
+	ScriptBinder::shutdown();
+
+	purgedir(keypaths.getLast("tmp"));
+	purgedir(keypaths.getLast("tmpfs"));
 
         if(signo == -2)
                 Bayonne::errlog("failed", "server exiting; no timeslots allocated");
@@ -90,38 +93,25 @@ static void version(void)
         exit(0);
 }
 
-static void loadStack(const char *id)
-{
-	BayonneDriver *d = BayonneDriver::loadDriver(keypaths.getLast("drivers"), id);
-
-	if(!d)
-	{
-		cerr << "bayonne cannot load " << id << " stack" << endl;
-		stop(-1);
-	}
-	d->start();
-}	
-
-static void loading(bool live)
+static void loading(void)
 {
 	char buffer[256];
 	char lang[32];
 	char ** keys;
-	const char *cp;
-	char *sp;
-	const char *dname = keyserver.getLast("driver");
+	char *plist[65];
+	const char *cp, *proto;
+	char *sp, *tok;
+	unsigned pcount = keyswitch.getIndex(plist, sizeof(plist) / sizeof(char **));
 	unsigned count = keyoptions.getCount("modules");
 	BayonneDriver *driver;
 	BayonneTranslator *translator = NULL;
 	static char vlib[64];
+	bool pflag = true;
 #ifdef	HAVE_LIBEXEC
 	size_t bs = 0;
 	int pri = 0;
 #endif
 
-	if(!live)
-		goto reload;
-
 	if(!Process::getEnv("SERVER_SYSEXEC"))
 		Process::setEnv("SERVER_SYSEXEC", keypaths.getLast("scripts"), true);
 	
@@ -149,13 +139,11 @@ static void loading(bool live)
 	getcwd(buffer, sizeof(buffer));
 
 	BayonneSysexec::allocate(keypaths.getLast("libexec"), bs, pri,
-	keypaths.getLast("modexec"));
+		keypaths.getLast("modexec"));
 #endif
-	PersistProperty::load();
-
         cp = keyserver.getLast("language");
         if(cp && (strlen(cp) == 2 || cp[2] == '_'))  
-		BayonneTranslator::loadTranslator(keypaths.getLast("phrases"), cp);  
+		BayonneTranslator::loadTranslator(cp);  
 
         cp = keyserver.getLast("voice");
         if(cp && strchr(cp, '/'))
@@ -165,7 +153,7 @@ static void loading(bool live)
                 if(sp)
                         *sp = 0;
                 if(strlen(lang) == 2 || sp[2] == '_')
-                        translator = BayonneTranslator::loadTranslator(keypaths.getLast("phrases"), lang);
+                        translator = BayonneTranslator::loadTranslator(lang);
 
 	}
 
@@ -197,9 +185,91 @@ static void loading(bool live)
 		}
         } 
 
-	driver = BayonneDriver::loadDriver(keypaths.getLast("drivers"), dname);
-	if(!driver)
-		stop(-1);
+	
+	cp = keyoptions.getLast("driver");
+	if(cp && *cp)
+	{
+		driver = BayonneDriver::loadDriver(cp);
+
+		if(!driver)
+			stop(-1);
+	}
+	else
+	{
+		proto = keyswitch.getLast("protocol");
+		if(proto && !strnicmp(proto, "no", 2))
+		{
+			pflag = false;
+			proto = NULL;
+		}
+
+		if(proto && !stricmp(proto, "yes"))
+			proto = NULL;
+
+                if(proto && !stricmp(proto, "use"))
+                        proto = NULL; 
+
+                if(proto && !stricmp(proto, "any"))
+                        proto = NULL; 
+
+                if(proto && !stricmp(proto, "all"))
+                        proto = NULL; 
+
+		if(proto && !*proto)
+			proto = NULL;
+
+		cp = keyswitch.getLast("trunking");
+		if(cp && *cp && strnicmp(cp, "no", 2))
+			BayonneDriver::loadTrunking(cp);
+		keys = plist;
+		if(pflag)
+			pflag = BayonneDriver::useProtocols();
+
+		while(*keys && BayonneDriver::useProtocols())
+		{
+			cp = keyswitch.getLast(*keys);
+			if(!cp)
+				cp = "";
+			pcount = atoi(cp);
+			cp = *keys;
+			if(proto && !stricmp(cp, proto))
+				pcount = 0;
+			else if(!stricmp(cp, "timeslots"))
+				pcount = 0;
+			else if(!stricmp(cp, "framing"))
+				pcount = 0;
+			else if(!stricmp(cp, "trunking"))
+				pcount = 0;
+			else if(!stricmp(cp, "protocol"))
+				pcount = 0;
+			else if(!stricmp(cp, "encoding"))
+				pcount = 0;
+			++keys;
+			if(!pcount)
+				continue;
+			BayonneDriver::loadProtocol(cp, pcount);
+		}
+		if(proto)
+			BayonneDriver::loadProtocol(proto, 0);
+	}	
+
+	sp = (char *)keyserver.getLast("monitoring");
+	if(sp && !strnicmp(sp, "no", 2))
+		sp = NULL;
+
+	if(sp && !*sp)
+		sp = NULL;
+
+	if(sp)
+		cp = strtok_r(sp, " ,;:\t", &tok);
+	else
+		cp = NULL;
+
+	while(cp)
+	{
+		Bayonne::loadMonitor(cp);
+		cp = strtok_r(NULL, " ,;:\t", &tok);
+	}
 
 	if(!count)
 		goto start;
@@ -207,33 +277,27 @@ static void loading(bool live)
 	keys = (char **)keyoptions.getList("modules");
 
 	while(*keys)
-		Bayonne::loadPlugin(keypaths.getLast("modules"), *keys++);
+		Bayonne::loadPlugin(*keys++);
 
 start:
-	if(!driver)
+	if(!BayonneDriver::getPrimary())
+	{
+		slog.critical("bayonne: no drivers loaded");
 		stop(-1);
+	}
 
-	driver->start();
+	BayonneDriver::start();
 	count = Bayonne::getTimeslotsUsed();
 	if(!count)
 		stop(-2);
 
-	Bayonne::start_driver = driver;
-
-	cp = keyoptions.getLast("sip.stack");
-	if(cp && atoi(cp) > 0)
-		loadStack("sip");
-
-	cp = keyoptions.getLast("h323.stack");
-	if(cp && atoi(cp) > 0)
-		loadStack("h323");
-
 	count = Bayonne::getTimeslotsUsed();
 
 #ifdef	HAVE_LIBEXEC
 	BayonneSysexec::startup();
 #endif
-reload:
+// reload
+	loadBinder(keyserver.getLast("binding"));
 	Bayonne::reload();
 	if(!Bayonne::compile_count)
 	{
@@ -242,10 +306,9 @@ reload:
 	}
 	else
 		Bayonne::errlog("notice", "%d applications compiled", Bayonne::compile_count); 
-	if(!live)
-		exit(0);
+
 	BayonneService::start();
-	Bayonne::errlog("notice", "%s driver started; %d timeslot(s) used", dname, count);
+	Bayonne::errlog("notice", "driver(s) started; %d timeslot(s) used", count);
 #ifndef	WIN32
         Process::setPosixSignal(SIGPIPE, SIG_IGN);
         Process::setPosixSignal(SIGINT, &stop);
@@ -270,51 +333,21 @@ static void logging(void)
 		slog.level(Slog::levelDebug);
 }
 
-static void checking(char **argv)
+static void checking(void)
 {
-	loadConfig();
 	keyserver.setValue("logging", "debug");
-	parseConfig(--argv);
 	logging();
-	loading(false);
+	if(!Bayonne::getTimeslotCount())
+		Bayonne::allocate(1, dynamic_cast<ScriptCommand *>(&runtime));
+	Bayonne::reload();
+        if(!Bayonne::compile_count)
+        {
+                Bayonne::errlog("critical", "no applications defined");
+                stop(-1);
+        }                                                                     
 	stop(0);
 }
 
-static void starting(char **argv, bool trace)
-{
-	loadConfig();
-	if(trace)
-		keyserver.setValue("logging", "debug");
-
-	parseConfig(argv);
-        Process::setScheduler(keyengine.getLast("scheduler"));
-	Process::setPriority(atoi(keyengine.getLast("priority")));
-#ifndef	WIN32
-	if(!getuid())
-	{
-		if(!Process::setUser(keyserver.getLast("user")))
-		{
-			Bayonne::errlog("fatal", "%s: cannot set user",
-				keyserver.getLast("user"));
-			stop(-1);
-		}
-	}
-	if(!trace)
-		Process::detach();
-
-	mainpid = getpid();
-#endif
-	
-	logging();
-        Bayonne::errlog("notice", "starting %s on %s %s; driver=%s, timeslots=%s",           
-		VERSION,
-                keyserver.getLast("cpu"), keyserver.getLast("platform"),
-		keyserver.getLast("driver"), keyserver.getLast("timeslots"));
-
-	loading(true);
-	Runtime::process();
-}
-
 #ifdef	WIN32
 
 static void control(DWORD request)
@@ -353,8 +386,6 @@ static VOID service(DWORD argc, LPTSTR *argv)
 
 	SetServiceStatus(hStatus, &sStatus);
 
-	starting(argv, false);
-
 	sStatus.dwCurrentState = SERVICE_RUNNING;
 	sStatus.dwControlsAccepted = SERVICE_ACCEPT_STOP | SERVICE_ACCEPT_SHUTDOWN;
 	sStatus.dwWin32ExitCode = 0;
@@ -373,27 +404,6 @@ static SERVICE_TABLE_ENTRY services[] =
 
 #endif
 
-static void testing(char **argv)
-{
-	testConfig(*argv);		
-	if(!parseConfig(argv))
-		Script::exec_extensions = "";
-
-        Process::setScheduler(keyengine.getLast("scheduler"));
-        Process::setPriority(atoi(keyengine.getLast("priority"))); 
-
-	logging();
-
-	Bayonne::errlog("notice", "testing %s on %s %s; driver=%s, timeslots=%s",
-		VERSION, 
-		keyserver.getLast("cpu"), keyserver.getLast("platform"),
-		keyserver.getLast("driver"), keyserver.getLast("timeslots"));
-
-	loading(true);
-	Runtime::process();
-}
-
-
 static void banner(void)
 {
 	cout << "SERVER VERSION " << VERSION << "; ";
@@ -407,17 +417,63 @@ int main(int argc, char **argv)
 {
 	char *cp;
 
-        if(argc < 2)
-        {
-                cerr << "use: bayonne --option [args...]" << endl;
-                exit(-1);
-        }
-#ifdef	HAVE_LIBEXEC
-	BayonneSysexec::setArgv0(argv[0]);
+	Script::use_macros = true;
+	Script::use_prefix = true;
+
+	if(argc == 2)
+	{
+		cp = argv[1];
+		if(!strncmp(cp, "--", 2))
+			++cp;
+		
+		if(!stricmp(cp, "-version"))
+			version();
+		else if(!stricmp(cp, "-check"))
+		{
+                	loadConfig();
+                	liveConfig();
+                	runtime.setValue("scripts", keypaths.getLast("scripts"));
+                	if(keypaths.getLast("addons"))
+                    		runtime.setValue("addons", keypaths.getLast("addons"));    
+                	runtime.setValue("include", keypaths.getLast("macros")); 
+			loadBinder(keyserver.getLast("binding"));
+			checking();
+		}
+#ifdef	HAVE_TESTING
+        	else if(!stricmp(cp, "-dump-install"))
+        	{
+                	loadConfig();
+                	liveConfig();
+                	banner();
+                	dumpConfig(keypaths);
+                	exit(0); 
+        	} 
+       		else if(!stricmp(cp, "-dump-testing"))
+        	{
+                	testConfig(*argv);
+                	liveConfig();    
+                	banner();
+                	dumpConfig(keypaths);
+                	exit(0);
+        	}
+#ifdef  WIN32
+        	else if(!stricmp(cp, "-dump-registry"))
+        	{
+                	// we assume these objects are registry initialized
+                	// and dump them without further processing.
+                	cout << "[paths]" << endl;   
+                	dumpConfig(keypaths);
+			cout << "[switch]" << endl;
+			dumpConfig(keyswitch);
+                	cout << "[server]" << endl;
+                	dumpConfig(keyserver);
+                	cout << "[engine]" << endl;
+                	dumpConfig(keyengine);
+                	exit(0);
+        	}
+#endif  
 #endif
-        cp = argv[1];
-        if(!strncmp(cp, "--", 2))
-                ++cp;
+	}
 
 #ifdef	WIN32
 	SetConsoleTitle("Bayonne");
@@ -437,62 +493,38 @@ int main(int argc, char **argv)
 
 #endif
 
-	if(!stricmp(cp, "-version"))
-		version();
-	else if(!stricmp(cp, "-debug"))
-	{
-		Mutex::setDebug(true);
-		testing(argv);
-	}
-	else if(!stricmp(cp, "-test"))
-		testing(argv);
-	else if(!stricmp(cp, "-trace") || !stricmp(cp, "-load"))
-		starting(argv, true);
-	else if(!stricmp(cp, "-check"))
-		checking(argv);
-	else if(!stricmp(cp, "-start"))
-	{
-#ifdef	WIN32
-		if(StartServiceCtrlDispatcher(services) == FALSE)
-		{
-			Bayonne::errlog("fatel", "service failed to start");
-			stop(-1);
-		}		
-#else
-		starting(argv, false);
-		return 0;
-#endif
-	}
-	else if(!stricmp(cp, "-dump-install"))
-	{
-		loadConfig();
-		banner();
-		dumpConfig(keypaths);
-		exit(0);
-	}
-	else if(!stricmp(cp, "-dump-testing"))
-	{
-		testConfig(*argv);
-		banner();
-		dumpConfig(keypaths);
-		exit(0);
-	}
-#ifdef	WIN32
-	else if(!stricmp(cp, "-dump-registry"))
-	{
-		// we assume these objects are registry initialized
-		// and dump them without further processing.
-		cout << "[paths]" << endl;
-		dumpConfig(keypaths);
-		cout << "[server]" << endl;
-		dumpConfig(keyserver);
-                cout << "[engine]" << endl;
-                dumpConfig(keyengine);
-		exit(0);
-	}
-#endif
+	Bayonne::provision_daemon = true;
+	loadConfig();
+	parseConfig(argv);
+	liveConfig();
+	if(Bayonne::provision_check)
+		checking();
 
-	cerr << "bayonne: " << *(argv + 1) << ": unknown option" << endl;
-	exit(-1);
-	return -1;
+	Process::setScheduler(keyengine.getLast("scheduler"));
+        Process::setPriority(atoi(keyengine.getLast("priority")));   
+#ifndef WIN32
+        if(!getuid())
+        {
+                if(!Process::setUser(keyserver.getLast("user")))
+                {
+                        Bayonne::errlog("fatal", "%s: cannot set user",
+                                keyserver.getLast("user"));
+                        stop(-1);
+                }
+        }
+	if(Bayonne::provision_daemon)
+		Process::detach();
+
+        mainpid = getpid();
+#endif
+	logging();
+        Bayonne::errlog("notice", "starting %s on %s %s; timeslots=%s",
+                VERSION,
+                keyserver.getLast("cpu"), keyserver.getLast("platform"),
+                keyswitch.getLast("timeslots"));   
+
+	loading();
+
+	Runtime::process();
+	return 0;
 }
