@@ -16,7 +16,11 @@
 
 #include "bayonne.h"
 
-#ifndef	WIN32
+#ifdef	WIN32
+#ifdef	_DEBUG
+#define	HAVE_TESTING
+#endif
+#else
 #include "private.h"
 #endif
 
@@ -108,40 +112,6 @@ public:
 	void clear(char *data, unsigned size);
 };
 
-class PersistProperty : public ScriptProperty, public Bayonne
-{
-private:
-	static ScriptSymbols syms;
-	static ThreadLock lock;
-	static bool loaded;
-
-#define	PERSIST_CACHE_SIZE 64
-
-	typedef	struct
-	{
-		char cache[PERSIST_CACHE_SIZE];
-		Symbol *sym;
-	} persist_t;
-
-public:
-	PersistProperty();
-
-	void set(const char *data, char *temp, unsigned size);
-
-	static bool remap(const char *id, char *save, const char *val = "");
-
-	static bool refresh(Symbol *sym, const char *ind, const char *val = "");
-
-	static bool test(const char *key);
-
-	static void save(void);
-
-	static void load(void);
-
-	static inline unsigned getSize(void)
-		{return sizeof(persist_t) + sizeof(ScriptProperty *);};
-};
-
 class TimeslotProperty : public ScriptProperty, public Bayonne
 {
 public:
@@ -156,18 +126,6 @@ public:
 //	void adjust(char *data, size_t size, long offset);
 };
 
-class Binder : public ScriptBinder, public ScriptChecks
-{
-private:
-        void attach(ScriptInterp *interp);
-        void detach(ScriptInterp *interp);  
-
-public:
-	Binder();
-
-	static Binder binder;
-};
-
 class Runtime : public ScriptRuntime, public Bayonne
 {
 protected:
@@ -180,7 +138,6 @@ protected:
 	static bool testDriver(ScriptInterp *interp, const char *v);
 	static bool testVoice(ScriptInterp *interp, const char *v);
 	static bool testLang(ScriptInterp *interp, const char *v);
-	static bool testKey(ScriptInterp *interp, const char *v);
 
 public:
 	static void process(void);
@@ -238,16 +195,8 @@ public:
 	bool scrTonegen(void);
 	bool scrDTMF(void);
 	bool scrMF(void);
-	bool scrCancel(void);
-	bool scrDetach(void);
-	bool scrStart(void);
 	bool scrTransfer(void);
-	bool scrWait(void);
-	bool scrJoin(void);
-	bool scrSignal(void);
-	bool scrFailsignal(void);
 	bool scrDial(void);
-	bool scrKey(void);
 };
 
 class Checks : public ScriptChecks, public Bayonne
@@ -255,12 +204,7 @@ class Checks : public ScriptChecks, public Bayonne
 public:
 	const char *chkConfig(Line *line, ScriptImage *img);
 	const char *chkPaths(Line *line, ScriptImage *img);
-	const char *chkKey(Line *line, ScriptImage *img);
-	const char *chkCDR(Line *line, ScriptImage *img);
 	const char *chkTonegen(Line *line, ScriptImage *img);
-	const char *chkRegister(Line *line, ScriptImage *img);
-	const char *chkAssign(Line *line, ScriptImage *img);
-	const char *chkSelect(Line *line, ScriptImage *img);
 	const char *chkSleep(Line *line, ScriptImage *img);
 	const char *chkCleardigits(Line *line, ScriptImage *img);
 	const char *chkKeyinput(Line *line, ScriptImage *img);
@@ -282,56 +226,31 @@ public:
 	const char *chkBuild(Line *line, ScriptImage *img);
 	const char *chkTone(Line *line, ScriptImage *img);
 	const char *chkDialer(Line *line, ScriptImage *img);
-	const char *chkCancel(Line *line, ScriptImage *img);
-	const char *chkStart(Line *line, ScriptImage *img);
 	const char *chkTransfer(Line *line, ScriptImage *img);
-	const char *chkWait(Line *line, ScriptImage *img);
-	const char *chkJoin(Line *line, ScriptImage *img);
-	const char *chkConnect(Line *line, ScriptImage *img);
 	const char *chkChildSignal(Line *line, ScriptImage *img);
 	const char *chkDial(Line *line, ScriptImage *img);
 };
 
-#ifdef	HAVE_LIBEXEC
-
-class Sysexec : protected Thread, protected Bayonne
-{
-private:
-	static bool exiting;
-	static int iopair[2];
-	static Sysexec *libexec;
-
-	static void execute(unsigned slot, const char *cmd);
-	static void readline(char *buf, unsigned max);
-
-	void run(void);
-
-	Sysexec();
-	~Sysexec();
-
-public:
-	static bool create(BayonneSession *s);
-	static void allocate(void);
-	static void cleanup(void);
-	static void startup(void);
-};
-
-#endif
-
 extern Runtime runtime;
 extern Keydata keypaths;
 extern Keydata keyserver;
 extern Keydata keyengine;
+extern Keydata keyswitch;
 extern Keydata keyoptions;
 
 extern TimeslotProperty typeTimeslot;
 extern PositionProperty typePosition;
 
 void purgedir(const char *dir);
+bool loadBinder(const char *id);
 void loadConfig(void);
-void testConfig(char *argv0);
+void liveConfig(void);
 void dumpConfig(Keydata &keydef);
 bool parseConfig(char **argv);
 
+#ifdef	HAVE_TESTING
+void testConfig(char *argv0);
+#endif
+
 }
 
